//
//   dir.h
//
//   Oliver Fromme  <olli@fromme.com>
//   @(#)$Id: dir.h,v 1.1 1998/12/04 09:04:38 olli Exp $
//

#ifndef HAVE_DIR_H
#define HAVE_DIR_H

static const char cvsid_dir_h[]
    = "@(#)$Id: dir.h,v 1.1 1998/12/04 09:04:38 olli Exp $";

#include <sys/types.h>
#include <sys/stat.h>

//
//   Struct for storing remote file information.
//
//   Supported file modes (also see mknod(2) and stat(2)):
//      S_IFREG   regular file
//      S_IFDIR   directory
//      S_IFLNK   symbolic link
//   Special devices and fifos are not supported (they are ignored).
//   Hardlinks are not supported (they are treated as separate files).
//
// *TODO* The three possible modes could be integrated into flags.
//

#define OFLAG_LEXISTS	0x0001	// file exists locally (for statistics)
#define OFLAG_EXCLUDE	0x0002	// exclude directory if empty

typedef struct {
	mode_t	mode;	// see above
	off_t	size;	// files/links: size, dirs: number of entries
	time_t	mtime;	// last modification time (UTC)
	time_t  tprec;	// precision of mtime (max. deviation) in seconds
	unsigned flags;	// see above
	char	*name;	// file name
	void	*data;	// files: NULL, links: *char, dirs: omifile[]
} omifile;

int parse_lslr (char *cptr, omifile *omidir, char *root);
void free_tree (omifile *omidir);
void debug_tree (char *rootname, omifile *omiroot);

#endif // HAVE_DIR_H

//-- 
